@@ -14,6 +14,10 @@ Usage::
         ListSimulationApplicationsPaginator,
         ListSimulationJobBatchesPaginator,
         ListSimulationJobsPaginator,
+        ListWorldExportJobsPaginator,
+        ListWorldGenerationJobsPaginator,
+        ListWorldTemplatesPaginator,
+        ListWorldsPaginator,
         RoboMakerClient,
     )
 
@@ -29,6 +33,10 @@ Usage::
     list_simulation_applications_paginator: ListSimulationApplicationsPaginator = client.get_paginator("list_simulation_applications")
     list_simulation_job_batches_paginator: ListSimulationJobBatchesPaginator = client.get_paginator("list_simulation_job_batches")
     list_simulation_jobs_paginator: ListSimulationJobsPaginator = client.get_paginator("list_simulation_jobs")
+    list_world_export_jobs_paginator: ListWorldExportJobsPaginator = client.get_paginator("list_world_export_jobs")
+    list_world_generation_jobs_paginator: ListWorldGenerationJobsPaginator = client.get_paginator("list_world_generation_jobs")
+    list_world_templates_paginator: ListWorldTemplatesPaginator = client.get_paginator("list_world_templates")
+    list_worlds_paginator: ListWorldsPaginator = client.get_paginator("list_worlds")
     ```
 """
 from mypy_boto3_robomaker.client import RoboMakerClient
@@ -40,6 +48,10 @@ from mypy_boto3_robomaker.paginator import (
     ListSimulationApplicationsPaginator,
     ListSimulationJobBatchesPaginator,
     ListSimulationJobsPaginator,
+    ListWorldExportJobsPaginator,
+    ListWorldGenerationJobsPaginator,
+    ListWorldsPaginator,
+    ListWorldTemplatesPaginator,
 )
 
 Client = RoboMakerClient
@@ -54,5 +66,9 @@ __all__ = (
     "ListSimulationApplicationsPaginator",
     "ListSimulationJobBatchesPaginator",
     "ListSimulationJobsPaginator",
+    "ListWorldExportJobsPaginator",
+    "ListWorldGenerationJobsPaginator",
+    "ListWorldTemplatesPaginator",
+    "ListWorldsPaginator",
     "RoboMakerClient",
 )
